==> atajo-ionic-0.0.15.tgz: package/src/lib/update/index.ts <==

import { Injectable } from '@angular/core';
import { CodePush, SyncStatus } from '@ionic-native/code-push';

import { Config } from '../config';

import { iDevice } from '../models/device';
import { Device } from '../device';
import { AlertController } from 'ionic-angular';
import { Utils } from '../utils'
import { Toast } from '../toast';

@Injectable()
export class Update {

    deploymentKey: string;
    device: iDevice;
    enabled: boolean;
    isAlertShowing: boolean;
    currentPackage: object;

    constructor(private codePush: CodePush, private deviceProvider: Device, private toastService: Toast, private alertCtrl: AlertController, private utilsProvider: Utils, private appConfig: Config) {

        console.log("PLATFORM IS : " + deviceProvider.getPlatformFromAgent())

        this.codePush.getCurrentPackage().then(details => {

            console.debug("CURRENT PACKAGE DETAILS : ", details);
            this.currentPackage = details;

        }).catch(error => {

            console.error("ERROR FETCHING CURRENT PACKAGE DETAILS");

        })


        if (['ios', 'android', 'windows'].indexOf(deviceProvider.getPlatformFromAgent()) > -1) {


            this.deploymentKey = this.appConfig.get('update.key.' + deviceProvider.getPlatformFromAgent(), false);
            this.enabled = true;
            this.isAlertShowing = false;

            this.getCurrent().then(current => {
                console.log("CURRENT IS : ", current);
            });

        } else {
            this.updateNotAvailable();
            this.enabled = false;
        }


    }

    public getCurrent() {

        if (!this.enabled) { this.updateNotAvailable(); return new Promise((resolve, reject) => { }); }
        return this.codePush.getCurrentPackage();

    }

    public checkForUpdate() {

        if (!this.enabled) { this.updateNotAvailable(); return; }

        console.log("CODE PUSH CHECKING FOR UPDATES WITH KEY : " + this.deploymentKey);



        this.codePush.checkForUpdate(this.deploymentKey).then((updateStatus) => {

            if (updateStatus === null) {
                console.log("CODE PUSH : APP IS UP TO DATE");
                return;
            }
            else {

                if (this.appConfig.get('update.silent', false)) {
                    this.sync();
                }
                else {

                    this.confirmUpdate(updateStatus);

                }
            }



            console.log("UPDATE PACKAGE STATUS IS : ", updateStatus);

        });





    }


    public sync() {

        if (!this.enabled) { this.updateNotAvailable(); return; }

        console.log("CODE PUSH CHECKING FOR UPDATES WITH KEY : " + this.deploymentKey);

        this.codePush.sync({ deploymentKey: this.deploymentKey }).subscribe((syncStatus) => {

            console.log('Sync Status: ', syncStatus);
            let message: string = "";

            switch (syncStatus) {

                case SyncStatus.UP_TO_DATE:
                    message = 'Your app is up to date!';
                    break;

                case SyncStatus.IN_PROGRESS:
                    message = 'An update is in progress ..';
                    break;

                case SyncStatus.CHECKING_FOR_UPDATE:
                    message = 'Checking for update ..';
                    break;

                case SyncStatus.DOWNLOADING_PACKAGE:
                    this.toastService.toast('Downloading package ..');
                    break;

                case SyncStatus.INSTALLING_UPDATE:
                    this.toastService.toast('Installing update ..');
                    break;

                case SyncStatus.UPDATE_INSTALLED:
                    this.confirmRestart();
                    break;

                case SyncStatus.ERROR:
                    this.toastService.toast('An update error occurred :( ...');
                    break;

                default:
                    message = 'An unhandled sync status ..';
                    break;


            }

            console.log("UPDATE STATUS MESSAGE : " + message);





        });


    }

    public restart() {

        this.codePush.restartApplication();
    }


    private confirmRestart() {

        if (this.isAlertShowing) { return; }
        this.isAlertShowing = true;

        let that = this;
        let alert = this.alertCtrl.create({
            title: 'Update Downloaded',
            message: 'A new update was installed and will be available on next app restart. <br><br> Would you like to restart the app now?',
            buttons: [
                {
                    text: 'NO',
                    role: 'cancel',
                    handler: () => { that.isAlertShowing = false; console.log('Restart Cancelled'); }
                },
                {
                    text: 'YES',
                    handler: () => { that.isAlertShowing = false; console.log('Restart Accepted'); that.restart(); }
                }
            ]
        });

        alert.present();
    }

    private confirmUpdate(details) {

        if (this.isAlertShowing) { return; }
        this.isAlertShowing = true;

        let that = this;
        let alert = this.alertCtrl.create({
            title: 'Update Version ' + details.appVersion,
            message: 'BUILD ' + details.packageHash.substring(0, 8) + ' (' + this.utilsProvider.bytesToSize(details.packageSize) + ')<br><br>' + details.description,
            buttons: [
                {
                    text: 'No Thanks',
                    role: 'cancel',
                    handler: () => { that.isAlertShowing = false; console.log('Update Cancelled'); }
                },
                {
                    text: 'UPDATE',
                    handler: () => { that.isAlertShowing = false; console.log('Update Accepted'); that.sync(); }
                }
            ]
        });

        alert.present();
    }

    public isSuccessful() {
        if (!this.enabled) { this.updateNotAvailable(); return; }
        this.codePush.notifyApplicationReady().then(message => {

            console.log("UPDATE APPLIED", message);

        }).catch(error => { console.error("CODE PUSH notifyAppReady ERROR : ", error) })
    }




    private updateNotAvailable() {

        console.warn('OTA UPDATES NOT AVAILABLE ON THIS DEVICE');

    }


}

==> atajo-ionic-0.0.33.tgz: package/src/lib/update/index.ts <==

import { Injectable } from '@angular/core';
import { CodePush, SyncStatus } from '@ionic-native/code-push';

import { Config } from '../config';

import { iDevice } from '../models/device';
import { Device } from '../device';
import { AlertController } from 'ionic-angular';
import { Utils } from '../utils'
import { Toast } from '../toast';

@Injectable()
export class Update {

    deploymentKey: string;
    device: iDevice;
    enabled: boolean;
    isAlertShowing: boolean;
    currentPackage: object;

    constructor(private codePush: CodePush, private deviceProvider: Device, private toastService: Toast, private alertCtrl: AlertController, private utilsProvider: Utils, private appConfig: Config) {


        console.debug("CHECKING IF CAN CODE PUSH");

        if (deviceProvider.isCordova()) {

            console.debug("CORDOVA FOUND -> INIT CODE PUSH");
            /*
                        this.codePush.getCurrentPackage().then(details => {
            
                            console.debug("CURRENT PACKAGE DETAILS : ", details);
                            this.currentPackage = details;
            
                        }).catch(error => {
            
                            console.error("ERROR FETCHING CURRENT PACKAGE DETAILS");
            
                        })
            
                        this.deploymentKey = this.appConfig.get('update.key.' + deviceProvider.getPlatformFromAgent(), false);
            */
            this.enabled = true;
            this.isAlertShowing = false;
            /*
                        this.getCurrent().then(current => {
                            console.log("CURRENT IS : ", current);
                        });
            */
        } else {
            this.updateNotAvailable();
            this.enabled = false;
        }


    }

    public getCurrent() {

        if (!this.enabled) { this.updateNotAvailable(); return new Promise((resolve, reject) => { }); }
        return this.codePush.getCurrentPackage();

    }

    public checkForUpdate() {

        if (!this.enabled) { this.updateNotAvailable(); return; }

        this.appConfig.getDeploymentKeys().then(key => {

            this.deploymentKey = key + "";
            console.log("CODE PUSH CHECKING FOR UPDATES WITH KEY : " + this.deploymentKey);
            this.getUpdate(this.deploymentKey);

        }).catch(error => {

            console.error("ERROR GETTING DEPLOYMENT KEYS ", error);

        })
    }

    private getUpdate(deploymentKey) {

        this.codePush.checkForUpdate(deploymentKey).then((updateStatus) => {

            if (updateStatus === null) {
                console.log("CODE PUSH : APP IS UP TO DATE");
                return;
            }
            else {

                if (this.appConfig.get('update.silent', false)) {
                    this.sync();
                }
                else {

                    this.confirmUpdate(updateStatus);
                }
            }

            console.log("UPDATE PACKAGE STATUS IS : ", updateStatus);

        });

    }


    public sync() {

        if (!this.enabled) { this.updateNotAvailable(); return; }

        console.log("CODE PUSH CHECKING FOR UPDATES WITH KEY : " + this.deploymentKey);

        this.codePush.sync({ deploymentKey: this.deploymentKey }).subscribe((syncStatus) => {

            console.log('Sync Status: ', syncStatus);
            let message: string = "";

            switch (syncStatus) {

                case SyncStatus.UP_TO_DATE:
                    message = 'Your app is up to date!';
                    break;

                case SyncStatus.IN_PROGRESS:
                    message = 'An update is in progress ..';
                    break;

                case SyncStatus.CHECKING_FOR_UPDATE:
                    message = 'Checking for update ..';
                    break;

                case SyncStatus.DOWNLOADING_PACKAGE:
                    this.toastService.toast('Downloading package ..');
                    break;

                case SyncStatus.INSTALLING_UPDATE:
                    this.toastService.toast('Installing update ..');
                    break;

                case SyncStatus.UPDATE_INSTALLED:
                    this.confirmRestart();
                    break;

                case SyncStatus.ERROR:
                    this.toastService.toast('An update error occurred :( ...');
                    break;

                default:
                    message = 'An unhandled sync status ..';
                    break;


            }

            console.log("UPDATE STATUS MESSAGE : " + message);





        });


    }

    public restart() {

        this.codePush.restartApplication();
    }


    private confirmRestart() {

        if (this.isAlertShowing) { return; }
        this.isAlertShowing = true;

        let that = this;
        let alert = this.alertCtrl.create({
            title: 'Update Downloaded',
            message: 'A new update was installed and will be available on next app restart. <br><br> Would you like to restart the app now?',
            buttons: [
                {
                    text: 'NO',
                    role: 'cancel',
                    handler: () => { that.isAlertShowing = false; console.log('Restart Cancelled'); }
                },
                {
                    text: 'YES',
                    handler: () => { that.isAlertShowing = false; console.log('Restart Accepted'); that.restart(); }
                }
            ]
        });

        alert.present();
    }

    private confirmUpdate(details) {

        if (this.isAlertShowing) { return; }
        this.isAlertShowing = true;

        console.debug("UPDATE.CONFIRMUPDATE WITH DETAILS : ", details);

        let that = this;
        let alert = this.alertCtrl.create({
            title: 'Update Version ' + details.appVersion,
            message: 'BUILD ' + details.packageHash.substring(0, 8) + ' (' + this.utilsProvider.bytesToSize(details.packageSize) + ')<br><br>' + details.description,
            buttons: [
                {
                    text: 'No Thanks',
                    role: 'cancel',
                    handler: () => { that.isAlertShowing = false; console.log('Update Cancelled'); }
                },
                {
                    text: 'UPDATE',
                    handler: () => { that.isAlertShowing = false; console.log('Update Accepted'); that.sync(); }
                }
            ]
        });

        alert.present();
    }

    public isSuccessful() {
        if (!this.enabled) { this.updateNotAvailable(); return; }
        this.codePush.notifyApplicationReady().then(message => {

            console.log("UPDATE APPLIED", message);

        }).catch(error => { console.error("CODE PUSH notifyAppReady ERROR : ", error) })
    }




    private updateNotAvailable() {

        console.warn('OTA UPDATES NOT AVAILABLE ON THIS DEVICE');

    }


}
